﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using Microsoft.SharePoint.Client;

namespace ManagedCSOMWeb.Pages
{
    public partial class Errors : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            string appWebUrl = Page.Request["SPAppWebUrl"];
            using (ClientContext ctx = new ClientContext(appWebUrl))
            {
                try
                {
                    //Fails because the object was not initialized
                    //Requires Load() and ExecuteQuery()
                    Console.WriteLine(ctx.Web.Title);
                }
                catch (PropertyOrFieldNotInitializedException x)
                {
                    Response.Write("<p>Property not initialized. " + x.Message + "</p>");
                }

                try
                {
                    //Fails because Skip() and Take() are meaningless
                    //in the context of a list collection
                    ctx.Load(ctx.Web, w => w.Lists.Skip(5).Take(10));
                    ctx.ExecuteQuery();
                }
                catch (InvalidQueryExpressionException x)
                {
                    Response.Write("<p>Invalid LINQ query. " + x.Message + "</p>");
                }

                try
                {
                    //Fails because InvalidObject is a meaningless object
                    InvalidObject o = new InvalidObject(ctx, null);
                    ctx.Load(o);
                    ctx.ExecuteQuery();
                }
                catch (ClientRequestException x)
                {
                    Response.Write("<p>Bad request. " + x.Message + "</p>");
                }

                try
                {
                    //Fails because the list does not exist
                    //The failure occurs on the server during processing
                    ctx.Load(ctx.Web, w => w.Lists);
                    List myList = ctx.Web.Lists.GetByTitle("Non-Existent List");
                    myList.Description = "A new description";
                    myList.Update();
                    ctx.ExecuteQuery();

                }
                catch (ServerException x)
                {
                    Response.Write("<p>Exception on server. " + x.Message + "</p>");
                }
            }

        }
    }

    class InvalidObject : ClientObject {
        public InvalidObject(ClientRuntimeContext c, ObjectPath p) : base(c, p) { }
    }
}